# Tango-Capo Change Log

## 0.3.1
* Added default image  
* More work on responsive themes and vertical navigation


## 0.3
* Vastly improved responsive 'vert' theme  
* Removed background on .content-body  
* Renamed .content-body to .entry-content to match hnews microformat  
* Moved padding and margin classes to mixins  
* Cleaned up horizontal and vertical navigation helpers  
* Much improved vertical navigation
